# Change Log

All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.0] - 2016-1-22

### Added

- Something
- Something else

### Changed

- Something
- Something else

### Fixed

- Something
- Something else
